==> skaffold-1.27.0.tar.gz: skaffold-1.27.0/ROADMAP.md <==
# 2021 Roadmap
Last updated: 03/09/2021

**What this roadmap is**

A list of features and concepts that we’d love to see in Skaffold over the next year. Some of these are motivated by direct community support, and some of them are things that we’re personally excited about and feel would enhance the experience of using Skaffold.

**What this roadmap is not**

A list of promises, or a hard timeline commitment. Some items on this list are still under consideration, and may be removed from the roadmap if we decide that they're not worth the engineering investment. At the time of writing this, though, we feel good about everything on this list and want to start a public conversation about it, so that we can use the community’s voice to help us drive the direction of Skaffold.

**Why we’re sharing this**

Feedback! We want to hear from each and every one of you: what are you personally excited about in Skaffold? What are the features that you most want to see? What would make your life easier? This is meant to be a public, living roadmap, where anyone can voice their opinions and we can get a true idea of where the broadest community support lies.

# Product Excellence
### Improve Developer Experience for Helm Users
### Identify and Address Performance Bottlenecks

# CI/CD
### Create a Clearer Separation of Manifest Management (`render`) and Deployment (`deploy`) Phases

# User Experience and Extensibility
### Pre- and Post- Phase Hooks
### Deploy Directly to Docker
### Multi-Architecture Container Builds
### Terminal UX Improvements
### Extensible Skaffold API

# Diagnostics and Debugging
### Improve Python Debug Support
### Improve Developer Assistance For Failures to Run/Debug Apps

# OSS Health and Community Engagement
### Reduce PR Review Latency
### Improve Issue Response Time

==> skaffold-1.38.0.tar.gz: skaffold-1.38.0/ROADMAP.md <==
# 2022 Roadmap
Last updated: 02/15/2022

**What this roadmap is**

A list of features and concepts that we’d love to see in Skaffold over the next year. Some of these are motivated by direct community support, and some of them are things that we’re personally excited about and feel would enhance the experience of using Skaffold.

**What this roadmap is not**

A list of promises, or a hard timeline commitment. Some items on this list are still under consideration, and may be removed from the roadmap if we decide that they're not worth the engineering investment. At the time of writing this, though, we feel good about everything on this list and want to start a public conversation about it, so that we can use the community’s voice to help us drive the direction of Skaffold.

**Why we’re sharing this**

Feedback! We want to hear from each and every one of you: what are you personally excited about in Skaffold? What are the features that you most want to see? What would make your life easier? This is meant to be a public, living roadmap, where anyone can voice their opinions and we can get a true idea of where the broadest community support lies.

# Product Excellence
### Improve Developer Experience for Helm Users
### Improve Skaffold Onboarding docs
### Revamp skaffold configuration to dissociate configuration from phase they are used and improve configuration reusability across modules.

# CI/CD
### Create a Clearer Separation of Manifest Management (`render`) and Deployment (`deploy`) Phases
### Post deployments tests


# User Experience and Extensibility
### Enable users to perform Cross Platform and Multi-Architecture Container Builds
### Polish Skaffold's Deployer platform extensibility.


# OSS Health and Community Engagement
### Reduce PR Review Latency
### Improve Issue Response Time
